@@ -12,6 +12,7 @@ from pathlib import Path
 import yaml
 
 from .base import Base
+from .logger import DEFAULT_TARGET_NAME
 from .exceptions import ConfigurationError
 
 # Pattern to validate configuration keys
@@ -31,6 +32,10 @@ class ConfigurationItemContainer(Base):
     __path_settings__ = ()
     """Tuple of settings loaded as pathlib.Path"""
 
+    def __init__(self, parent=None, debug_enabled=False, silent=False, logger=DEFAULT_TARGET_NAME):
+        self.__attributes__ = []
+        super().__init__(parent, debug_enabled, silent, logger)
+
     @property
     def __config_root__(self):
         """
@@ -86,6 +91,19 @@ class ConfigurationItemContainer(Base):
         if not RE_CONFIGURATIION_KEY.match(attr):
             raise ConfigurationError(f'Invalid attribute name: {attr}')
 
+    def as_dict(self):
+        """
+        Return VS code configuration section as dictionary
+        """
+        data = {}
+        for attribute in self.__attributes__:
+            item = getattr(self, attribute)
+            if hasattr(item, 'as_dict'):
+                data[attribute] = item.as_dict()
+            else:
+                data[attribute] = item
+        return data
+
     def set(self, attr, value):
         """
         Load item with correct class
@@ -95,11 +113,13 @@ class ConfigurationItemContainer(Base):
         if isinstance(value, dict):
             item = self.__dict_loader__(value, parent=self)  # pylint: disable=not-callable
             setattr(self, attr, item)
+            self.__attributes__.append(attr)
             return
 
         if isinstance(value, (list, tuple)):
             item = self.__list_loader__(attr, value, parent=self)  # pylint: disable=not-callable
             setattr(self, item.__setting__, item)
+            self.__attributes__.append(item.__setting__)
             return
 
         if value is not None:
@@ -127,6 +147,7 @@ class ConfigurationItemContainer(Base):
             raise ConfigurationError(f'Error formatting setting {attr}: {error}') from error
 
         setattr(self, attr, value)
+        self.__attributes__.append(attr)
 
 
 class ConfigurationList(ConfigurationItemContainer):
@@ -226,6 +247,7 @@ class ConfigurationSection(ConfigurationItemContainer):
             if name is None:
                 raise ConfigurationError(f'Subsection class defines no name: {loader}')
             setattr(self, name, subsection)
+            self.__attributes__.append(name)
 
     def __attribute_from_key__(self, key):
         """
@@ -373,6 +395,15 @@ class ConfigurationSection(ConfigurationItemContainer):
             else:
                 self.set(key, value)
 
+    def as_dict(self):
+        """
+        Return configuration section as dictionary
+        """
+        data = super().as_dict()
+        for subsection in self.__subsections__:
+            data[subsection.__name__] = subsection.as_dict()
+        return data
+
     def set(self, attr, value):
         """
         Set configuration setting value as attribute of the object
